==> kubernetes-model-autoscaling-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v1/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerSpecFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getMaxReplicas();
  public A withMaxReplicas(java.lang.Integer maxReplicas);
  public java.lang.Boolean hasMaxReplicas();
  public java.lang.Integer getMinReplicas();
  public A withMinReplicas(java.lang.Integer minReplicas);
  public java.lang.Boolean hasMinReplicas();
  
  /**
   * This method has been deprecated, please use method buildScaleTargetRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference getScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference buildScaleTargetRef();
  public A withScaleTargetRef(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference scaleTargetRef);
  public java.lang.Boolean hasScaleTargetRef();
  public A withNewScaleTargetRef(java.lang.String apiVersion,java.lang.String kind,java.lang.String name);
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference item);
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference item);
  public java.lang.Integer getTargetCPUUtilizationPercentage();
  public A withTargetCPUUtilizationPercentage(java.lang.Integer targetCPUUtilizationPercentage);
  public java.lang.Boolean hasTargetCPUUtilizationPercentage();
  public interface ScaleTargetRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{
    public N and();
    public N endScaleTargetRef();
    
  }
  
}

==> kubernetes-model-autoscaling-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v1/HorizontalPodAutoscalerSpecFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HorizontalPodAutoscalerSpecFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Integer getMaxReplicas();
  public A withMaxReplicas(java.lang.Integer maxReplicas);
  public java.lang.Boolean hasMaxReplicas();
  public java.lang.Integer getMinReplicas();
  public A withMinReplicas(java.lang.Integer minReplicas);
  public java.lang.Boolean hasMinReplicas();
  
  /**
   * This method has been deprecated, please use method buildScaleTargetRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference getScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference buildScaleTargetRef();
  public A withScaleTargetRef(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference scaleTargetRef);
  public java.lang.Boolean hasScaleTargetRef();
  public A withNewScaleTargetRef(java.lang.String apiVersion,java.lang.String kind,java.lang.String name);
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference item);
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
  public io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReference item);
  public java.lang.Integer getTargetCPUUtilizationPercentage();
  public A withTargetCPUUtilizationPercentage(java.lang.Integer targetCPUUtilizationPercentage);
  public java.lang.Boolean hasTargetCPUUtilizationPercentage();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ScaleTargetRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v1.CrossVersionObjectReferenceFluent<io.fabric8.kubernetes.api.model.autoscaling.v1.HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{
    public N and();
    public N endScaleTargetRef();
    
  }
  
}
